@@ -1,6 +1,7 @@
 package Unexpected::Types;
 
-use strictures;
+use strict;
+use warnings;
 
 use English               qw( -no_match_vars );
 use Module::Runtime       qw( is_module_name require_module );
@@ -13,7 +14,8 @@ use Type::Utils           qw( as coerce extends from
                               inline_as message subtype via where );
 use Unexpected::Functions qw( inflate_message );
 
-use namespace::clean -except => 'meta';
+# TODO: Is this causing the &warnings::bits undefined error?
+#use namespace::clean -except => 'meta';
 
 BEGIN { extends 'Types::Standard' };
 
